@@ -3,7 +3,7 @@ package Dancer2::Plugin::Auth::Extensible::Provider::Base;
 use strict;
 use Crypt::SaltedHash;
 
-our $VERSION = '0.306';
+our $VERSION = '0.400';
 
 =head1 NAME
 
@@ -31,10 +31,43 @@ sub new {
     return bless $self => $class;
 }
 
+=head1 METHODS SUPPLIED BY BASE PROVIDER
+
+=head2 realm_settings
+
+Accessor for realm settings.
+
+=head2 realm_dsl
+
+Accessor for realm DSL object.
+
+=head2 match_password($given, $correct)
+
+Matches C<$given> password with the C<$correct> one.
+
+=head2 encrypt_password($password, $algorithm)
+
+Encrypts password C<$password> with C<$algorithm> which defaults to SHA-1.
+
+=head1 METHODS IMPLEMENTED BY PROVIDER
+
+=head2 authenticate_user
+
+=head2 get_user_details
+
+=head2 set_user_details
+
+=head2 get_user_roles
+
+=head2 set_user_password
+
+=head2 password_expired
+
+=cut
+
 sub realm_settings { shift->{realm_settings} || {} }
 sub realm_dsl { shift->{dsl} }
 
- 
 sub match_password {
     my ($self, $given, $correct) = @_;
 
@@ -60,6 +93,16 @@ sub match_password {
 }
 
 
+sub encrypt_password {
+    my ($self, $password, $algorithm) = @_;
+    $algorithm ||= 'SHA-1';
+    my $crypt = Crypt::SaltedHash->new(algorithm => $algorithm);
+    $crypt->add($password);
+    $crypt->generate;
+}
+
+
+
 # Install basic method placeholders which will blow up if the provider module
 # did not implement their own version. 
 {
@@ -67,7 +110,10 @@ sub match_password {
     for my $method (qw(
         authenticate_user
         get_user_details
+        set_user_details
         get_user_roles
+        set_user_password
+        password_expired
         ))
     {
         *$method = sub {
